----------
-- variables
----------
local realmTotalGold
local tooltipText = "To|r|cffffff00 delete|r entries |r|cff44ff44Shift|r+|r|cff44ff44LeftClick|r on a given name.\nThe entry will be deleted and a UI reload is triggered."

-- unique identifier, to provide update to the correct money frame: RealmName+CharName
local uniqueCharID

GoldDB = {}
minimapDB = {}

----------
-- Frame building
----------
local UINGold = CreateFrame("Frame", "nakaGold_frame", UIParent, "UIPanelDialogTemplate");
UINGold.ScrollFrame = CreateFrame("ScrollFrame", nil, UINGold, "UIPanelScrollFrameTemplate");
local child = CreateFrame("Frame", nil, UINGold.ScrollFrame);

-- minimap button
local icon = LibStub("LibDBIcon-1.0")
local LDB = LibStub("LibDataBroker-1.1"):NewDataObject("nakaGold", {
	type = "data source",
	text = "nakaGold",
	icon = "Interface\\AddOns\\nakaGold\\Textures\\nakaGold",
	OnClick = function(button,buttonPressed)
		local shift_key = IsShiftKeyDown()
		
		if buttonPressed == "RightButton" then
			if minimapDB.lock == true then
				icon:Unlock("nakaGold")
				minimapDB.lock = false
			else
				icon:Lock("nakaGold")
				minimapDB.lock = true
			end
		end
		
		if buttonPressed == "LeftButton" then
			
			if shift_key then
				icon:Hide("nakaGold")
				minimapDB.show = false
			else
				nakaGold_toggleGUI()
			end
			
			
		end
	end,
	OnTooltipShow = function(tooltip)
		if not tooltip or not tooltip.AddLine then return end
		tooltip:AddLine("|r|cffffffffnakaGold|r")
		tooltip:AddLine("|r|cff44ff44Left-click|r to toggle AddOn Window")
		tooltip:AddLine("|r|cff44ff44Right-click|r to |r|cffff000dlock|r Minimap Button")
		tooltip:AddLine("|r|cff44ff44Shift|r+|r|cff44ff44Left-click|r to |r|cffff000dhide|r Minimap Button")
		tooltip:AddLine("|r|cff44ff44/ng minimap|r in chat to |r|cffff000dtoggle|r Minimap Buton")
	end,
})

----------
-- NGold functions
----------

-- to enable smooth scrolling in scrolling frame
local function ScrollFrame_OnMouseWheel(self, delta)
	local newValue = self:GetVerticalScroll() - (delta * 25);
	
	if (newValue < 0) then
		newValue = 0;
	elseif (newValue > self:GetVerticalScrollRange()) then
		newValue = self:GetVerticalScrollRange();
	end
	
	self:SetVerticalScroll(newValue);
end

-- remove a character
function nakaGold_deleteEntry(self, button)
	local alt_key = IsAltKeyDown()
	local shift_key = IsShiftKeyDown()
	local control_key = IsControlKeyDown()
	

	if button == "LeftButton" then
		--print("LINKSKLICK2")
		if alt_key then
			--DoAltStuff
		elseif shift_key then
			--DoShiftStuff
			
			--print("SHIFT+LINKSKLICK")
			--print("Frame name:   " .. self:GetName())
			
			--print("Frame Text:   " .. self:GetText())
			
			-- getting frame name and splitting it up into realmname and charname
			-- framename was constructed to be realmname_charname as an unique identifier
			string = self:GetName()
			local realmName, charName = string:match("([^,]+)_([^,]+)")
			
			-- delete entry
			GoldDB[realmName][charName] = nil
			
			-- trying to update the UI
			-- TODO: try to find a more elegant solution
			ReloadUI();
			
		elseif control_key then
			--DoControlStuff
		else -- No modifier key is pressed
			--DoStuff
	end
	elseif button == "RightButton" then
			--DoMoreStuff
	end

end

-- update gold frame and totals
function nakaGold_goldUpdate(self)
	
	local realmName = GetRealmName()
	local charName = UnitName("player");
	local charMoney = GetMoney();
	
	-- remove spaces from realm name
	local realmName = string.gsub(realmName, "%s+", "")
	
	-- update savedvariable
	GoldDB[realmName][charName]["gold"] = charMoney
		
	-- unique identifier, to provide update to the correct money frame: RealmName+CharName
	local uniqueCharGoldID = realmName .. "_" .. charName .. "Gold"
	
	MoneyFrame_Update(uniqueCharGoldID, charMoney)
	MoneyFrame_Update(realmName, nakaGold_realmTotal(realmName))
	MoneyFrame_Update("totalGold", nakaGold_totalTotal())
	
	-- access global variables for goldframe (realm), fontstring realm name, fontstring for the brackets (realm total)
	local goldframeRealmName = _G[realmName];
	local fontstringBracketOpen = _G["bracketOpen"..realmName]
	local fontstringBracketClose = _G["bracketClose"..realmName]
	local fontstringRealmName = _G["Realm"..realmName]
	
	-- update the brackets for the realm total gold 
	fontstringBracketOpen:SetPoint("LEFT", fontstringRealmName, "LEFT", fontstringRealmName:GetWidth()+14, 0)
	fontstringBracketClose:SetPoint("LEFT", fontstringRealmName, "LEFT", fontstringRealmName:GetWidth()+goldframeRealmName:GetWidth()+10, 0)
end

-- calcualte realm gold
function nakaGold_realmTotal(realm)
	local realmTotalGold = 0
	for key, value in pairs(GoldDB[realm]) do
		realmTotalGold = realmTotalGold + value["gold"]
	end
	return realmTotalGold
end

-- calcualte total gold
function nakaGold_totalTotal()
	local totalTotalGold = 0
	for realm, value in pairs(GoldDB) do
		for key, value in pairs(GoldDB[realm]) do
			totalTotalGold = totalTotalGold + value["gold"]
		end
	end
	--print("totalTotal:  " .. totalTotalGold)
	return totalTotalGold
end

-- initilize GUI
function nakaGold_initGUI()
	UINGold:SetSize(365, 450); -- width, height
	UINGold:SetPoint("CENTER", UIParent, "CENTER"); -- point, relativeFrame, relativePoint, xOffset, yOffset
	
	UINGold:SetFrameStrata("High")
	
	UINGold:SetMovable(true)
	UINGold:EnableMouse(true)
	UINGold:RegisterForDrag("LeftButton")
	UINGold:SetScript("OnDragStart", UINGold.StartMoving)
	--UINGold:SetScript("OnDragStart", UINGold.StartSizing)
	
	UINGold:SetScript("OnDragStop", UINGold.StopMovingOrSizing)
	
	
	UINGold.TooltipFrame = CreateFrame("Frame", nil, UINGold)
	UINGold.TooltipFrame:SetPoint("RIGHT", nakaGold_frameTitleBG, "RIGHT", 0, 0)
	UINGold.TooltipFrame:SetSize(80, 20)
	UINGold.TooltipFrame:SetBackdropColor(0.5,0.5,0.5,0.8)
	
	UINGold.TooltipFrameText = UINGold:CreateFontString(nil, "Overlay")
	UINGold.TooltipFrameText:SetFontObject("GameFontNormal")
	UINGold.TooltipFrameText:SetPoint("Right", UINGold.TooltipFrame, "CENTER", 10, 0)
	UINGold.TooltipFrameText:SetText("(info)")
	
	UINGold.TooltipFrame:SetScript("OnEnter",function(...)
		GameTooltip:SetOwner(UINGold.title, "ANCHOR_TOP", 105, 5)
		GameTooltip:SetText(tooltipText,1,1,1,0.9)
		GameTooltip:Show()
	end)
	UINGold.TooltipFrame:SetScript("OnLeave",function(...)
		GameTooltip:Hide()
	end)

	UINGold.title = UINGold:CreateFontString(nil, "Overlay"); -- create FontString
	UINGold.title:SetFontObject("GameFontHighlight"); -- selecting a "Font", could have also used UINGold.title:SetFont("Fonts\\FRIZQT__.ttf, 11, "OUTLINE");
	UINGold.title:SetPoint("LEFT", nakaGold_frameTitleBG, "LEFT", 10, 0); -- set position of the font
	UINGold.title:SetText("nakaGold - Gold overview"); -- set text of the font
	
	
	
	UINGold.ScrollFrame:SetClipsChildren(true);

	UINGold.ScrollFrame:SetPoint("TOPLEFT", nakaGold_frameDialogBG, "TOPLEFT", 4, -8);
	UINGold.ScrollFrame:SetPoint("BOTTOMRIGHT", nakaGold_frameDialogBG, "BOTTOMRIGHT", -3, 4);
	UINGold.ScrollFrame:SetScript("OnMouseWheel", ScrollFrame_OnMouseWheel);
	
	UINGold.ScrollFrame.ScrollBar:ClearAllPoints();
	UINGold.ScrollFrame.ScrollBar:SetPoint("TOPLEFT", UINGold.ScrollFrame, "TOPRIGHT", -12, -18);
	UINGold.ScrollFrame.ScrollBar:SetPoint("BOTTOMRIGHT", UINGold.ScrollFrame, "BOTTOMRIGHT", -7, 18);

	-- will be set in the initMoney function when it is clear how big the "scroll frame" needs to be
	--child:SetSize(320, 700);
	
	--child.bg = child:CreateTexture(nil, "BACKGROUND");
	--child.bg:SetAllPoints(true)
	--child.bg:SetColorTexture(0, 0.6, 0, 0.2)
	
	UINGold.ScrollFrame:SetScrollChild(child);	
		
	UINGold:Hide()
	

			
	return UINGold
end

-- initilize money / moneyframes
function nakaGold_initMoney()
	local realmName = GetRealmName()
	local charName = UnitName("player");
	local charMoney = GetMoney();
	local faction = UnitFactionGroup("player")
	
	local realmName = string.gsub(realmName, "%s+", "")
	
	--local uniqueName = realmName .. charName
	
	-- initialize table if empty
	if (not GoldDB) then -- intitialize table
		GoldDB = {}
		--print("initialize table")
	end

	if (not GoldDB[realmName]) then -- intitialize realm
		GoldDB[realmName] = {}
		--print("initialize realm")
	end

	if (not GoldDB[realmName][charName]) then -- initialize character
		GoldDB[realmName][charName] = {}
		GoldDB[realmName][charName]["gold"] = 0
		GoldDB[realmName][charName]["faction"] = faction
		--print("initialize char")
	end	
	
	-- sort realms because pairs() is to dumb to keep the order
	sortedRealms = {}
	for n in pairs(GoldDB) do table.insert(sortedRealms, n) end
	table.sort(sortedRealms)
	
	
	-- Total header
	UINGold.totalGold = UINGold.ScrollFrame:CreateFontString(nil, "Overlay")
	UINGold.totalGold:SetFontObject("GameFontHighlightLarge")
	--UINGold.totalGold:SetPoint("TOPLEFT", UINGold, "TOPLEFT", 25, -50)
	UINGold.totalGold:SetPoint("TOPLEFT", child, "TOPLEFT", 10, -10)
	UINGold.totalGold:SetText("TOTAL: ")
	
	--[[ -- old stuff, without a scroll frame
	-- Total header
	UINGold.totalGold = UINGold:CreateFontString(nil, "Overlay")
	UINGold.totalGold:SetFontObject("GameFontHighlightLarge")
	--UINGold.totalGold:SetPoint("TOPLEFT", UINGold, "TOPLEFT", 25, -50)
	UINGold.totalGold:SetPoint("TOPLEFT", child, "TOPLEFT", 0, 0)
	UINGold.totalGold:SetText("TOTAL: ")
	]]	

	-- Total Gold
	local NGMoney = CreateFrame("Frame", "totalGold", UINGold.ScrollFrame, "SmallMoneyFrameTemplate")
	NGMoney:SetPoint("LEFT", UINGold.totalGold, "LEFT", 80, 1)
	NGMoney:SetScale(1.1)
	MoneyFrame_SetType(NGMoney, "STATIC") -- seems to be necessary so that the total isn't wiped out when opening a mail box
	MoneyFrame_Update("totalGold", nakaGold_totalTotal())
	
	-- initial offsett
	local yRealmOffset = -40		-- initial offset from top for first realm name that is found
	local y = -40					-- offsett that will get increased so new lines will be "simulated" (based of frame of realm name)
	
	local allianceFound = 0
	local hordeFound = 0
	
	
	for i, realm in ipairs(sortedRealms) do
		--print(" FOR BEGINN ::::::::::::")
		--print(" ")
		--print("CURRENT ACTIVE REALM ------- " .. realm)
		--print(" ")
		
		-- variable to check if there is an alliance character for given realm saved
		local allianceFound = 0
		local hordeFound = 0
		
		-- actual FOR check to see if there is an alliance character
		for key, value in pairs(GoldDB[realm]) do
			if value["faction"] == "Alliance" then
				allianceFound = 1
				--print("Alliance found " .. " " .. key .. " " .. allianceFound)	
			end
			if value["faction"] == "Horde" then
				hordeFound = 1
				--print("Horde found " .. " " .. key .. " " .. allianceFound)	
			end
		end
		
		-- sort names because pairs() is to dumb to keep the order
		sortedNames = {}
		for n in pairs(GoldDB[realm]) do table.insert(sortedNames, n) end
		table.sort(sortedNames)
		--print("sortedNames for " .. realm .. " --- " .. n)
		
		-- to check if a realm has any chars in it (an emmpty server can be caused by deleting characters)
		if allianceFound == 0 and hordeFound == 0 then
			--print("Realm is empty: " .. realm)
						
		else
			--print("Realm has chars " .. realm)
			
				
			local y = -20
			
			-- RealmName header: yRealmOffset in first round -80, will be increased in loop for each name / faction
			UINGold.realm = UINGold.ScrollFrame:CreateFontString("Realm"..realm, "Overlay")
			UINGold.realm:SetFontObject("GameFontHighlightLarge")
			UINGold.realm:SetTextColor(0.6,0.6,0.9,1)
			UINGold.realm:SetPoint("TOPLEFT", child, "TOPLEFT", 10, yRealmOffset)
			UINGold.realm:SetText(realm)
			yRealmOffset = yRealmOffset - 30
			
			-- Realm total Gold (next to realm name)
			local NGMoney = CreateFrame("Frame", realm, UINGold.ScrollFrame, "SmallMoneyFrameTemplate")
			NGMoney:SetPoint("LEFT", UINGold.realm, "LEFT", UINGold.realm:GetWidth()+20, -1)
			MoneyFrame_SetType(NGMoney, "STATIC") -- seems to be necessary so that the total isn't wiped out when opening a mail box
			MoneyFrame_Update(realm, nakaGold_realmTotal(realm))
			
			-- put brackets around realm total
			UINGold.bracketOpen = UINGold.ScrollFrame:CreateFontString("bracketOpen"..realm, "Overlay")
			UINGold.bracketOpen:SetFontObject("GameFontHighlightLarge")
			UINGold.bracketOpen:SetTextColor(0.98,0.72,0.01,1)
			UINGold.bracketOpen:SetPoint("LEFT", UINGold.realm, "LEFT", UINGold.realm:GetWidth()+14, 0)
			UINGold.bracketOpen:SetText("[")
			
			UINGold.bracketClose = UINGold.ScrollFrame:CreateFontString("bracketClose"..realm, "Overlay")
			UINGold.bracketClose:SetFontObject("GameFontHighlightLarge")
			UINGold.bracketClose:SetTextColor(0.98,0.72,0.01,1)
			UINGold.bracketClose:SetPoint("LEFT", UINGold.realm, "LEFT", UINGold.realm:GetWidth()+NGMoney:GetWidth()+10, 0)
			UINGold.bracketClose:SetText("]")
		
					
			if allianceFound == 1 then
			-- loop for Alliance (1st)
			--print("LOOP Alliance ------- " .. realm)
			--print(" ")
				-- Faction header: offset = constant, Alliance would be always the first thing after realm
				UINGold.faction = UINGold.ScrollFrame:CreateFontString(nil, "Overlay")
				UINGold.faction:SetFontObject("GameFontHighlight")
				UINGold.faction:SetTextColor(0.2,0.5,1,1)
				UINGold.faction:SetPoint("LEFT", UINGold.realm, "LEFT", 15, -20)
				UINGold.faction:SetText("Alliance")
				yRealmOffset = yRealmOffset - 20
				
				for i,n in ipairs(sortedNames) do
				
						
					 for key, value in pairs(GoldDB[realm]) do
						-- Key: Name of the character
						-- value: the value of  "faction" or "gold"
												
						if n == key and value["faction"] == "Alliance" then
							-- unique identifier, to provide update to the correct money frame: RealmName+CharName+("Gold")
							local uniqueCharID = realm .. "_" .. key
							local uniqueCharGoldID = realm .. "_" .. key .. "Gold"
							
							-- creating a frame because fontstring is unable to have a SetScript statement
							-- soley used for click event (to delete entry)
							UINGold.nameFrame = CreateFrame("Frame", uniqueCharID, UINGold.ScrollFrame);
							UINGold.nameFrame:SetPoint("LEFT", UINGold.faction, "LEFT", 10, y); 
							UINGold.nameFrame:SetAlpha(0.5)
							UINGold.nameFrame:SetScript("OnMouseUp", nakaGold_deleteEntry)
							
							
							-- frontstring with name
							UINGold.name = UINGold.ScrollFrame:CreateFontString(nil, "Overlay");
							UINGold.name:SetFontObject("GameFontHighlight");
							if key == charName then -- change color of active toon to yellow
								UINGold.name:SetFontObject("GameFontNormal")
							end
							UINGold.name:SetPoint("LEFT", UINGold.faction, "LEFT", 10, y); 
							UINGold.name:SetText(key)
							UINGold.nameFrame:SetSize(UINGold.name:GetWidth(),UINGold.name:GetHeight())
							
							
							--[[
							-- name fronstring
							UINGold.name = UINGold.ScrollFrame:CreateFontString(uniqueCharID, "Overlay");
							UINGold.name:SetFontObject("GameFontHighlight");
							if key == charName then -- change color of active toon to white
								UINGold.name:SetFontObject("GameFontNormal")
								--UINGold.name:SetTextColor(1,1,1,1)
							end
							UINGold.name:SetPoint("LEFT", UINGold.faction, "LEFT", 10, y); 
							UINGold.name:SetText(key)
							--UINGold.name:SetScript("OnClick", nakaGold_deleteEntry)
							]]
											
							local NGMoney = CreateFrame("Frame", uniqueCharGoldID, UINGold.ScrollFrame, "SmallMoneyFrameTemplate")
							NGMoney:SetPoint("Right", UINGold.name, "LEFT", 285, 0)
							--NGMoney:SetScale(1)
							MoneyFrame_SetType(NGMoney, "STATIC") -- seems to be necessary so that the total isn't wiped out when opening a mail box
							MoneyFrame_Update(uniqueCharGoldID, value["gold"])
							y = y - 20
							yRealmOffset = yRealmOffset - 20
							
							--print("yRealmOffset (inner most): " .. yRealmOffset)
							--print("y realm (in schleife): " .. yRealmOffset)
						end
					end
				end	
			
			end
			
			if hordeFound == 1 then
			-- loop for Horde (2nd)
			--print("LOOP Horde ------- " .. realm)
			--print(" ")
				-- Faction header: offset = constant, Alliance would be always the first thing after realm
				UINGold.faction = UINGold.ScrollFrame:CreateFontString(nil, "Overlay")
				UINGold.faction:SetFontObject("GameFontHighlight")
				UINGold.faction:SetTextColor(1,0.2,0.1,1)
				if allianceFound == 1 then				
					UINGold.faction:SetPoint("LEFT", UINGold.realm, "LEFT", 15, y-20)
				else
					-- need to remove the extra line if there is no alliance
					UINGold.faction:SetPoint("LEFT", UINGold.realm, "LEFT", 15, y)
				end
				UINGold.faction:SetText("Horde")
				yRealmOffset = yRealmOffset - 20
				
				-- reset offset for character names, needs to be reset to -20 so that the names of horder characters are one line below the faction frame
				local y = -20
				for i,n in ipairs(sortedNames) do
				
						
					 for key, value in pairs(GoldDB[realm]) do
						-- Key: Name of the character
						-- value: the value of  "faction" or "gold"
												
						if n == key and value["faction"] == "Horde" then
							-- unique identifier, to provide update to the correct money frame: RealmName+CharName+("Gold")
							local uniqueCharID = realm .. "_" .. key
							local uniqueCharGoldID = realm .. "_" .. key .. "Gold"
							
							-- creating a frame because fontstring is unable to have a SetScript statement
							-- soley used for click event (to delete entry)
							UINGold.nameFrame = CreateFrame("Frame", uniqueCharID, UINGold.ScrollFrame);
							UINGold.nameFrame:SetPoint("LEFT", UINGold.faction, "LEFT", 10, y); 
							UINGold.nameFrame:SetAlpha(0.5)
							UINGold.nameFrame:SetScript("OnMouseUp", nakaGold_deleteEntry)
							
							
							
							-- frontstring with name
							UINGold.name = UINGold.ScrollFrame:CreateFontString(nil, "Overlay");
							UINGold.name:SetFontObject("GameFontHighlight");
							if key == charName then -- change color of active toon to yellow
								UINGold.name:SetFontObject("GameFontNormal")
							end
							UINGold.name:SetPoint("LEFT", UINGold.faction, "LEFT", 10, y); 
							UINGold.name:SetText(key)
							UINGold.nameFrame:SetSize(UINGold.name:GetWidth(),UINGold.name:GetHeight())
							
							--[[
							-- name fronstring
							UINGold.name = UINGold.ScrollFrame:CreateFontString(uniqueCharID, "Overlay");
							UINGold.name:SetFontObject("GameFontHighlight");
							if key == charName then -- change color of active toon to white
								UINGold.name:SetFontObject("GameFontNormal")
								--UINGold.name:SetTextColor(1,1,1,1)
							end
							UINGold.name:SetPoint("LEFT", UINGold.faction, "LEFT", 10, y);
							--UINGold.name:SetScript("OnClick", nakaGold_deleteEntry)
							UINGold.name:SetText(key)
							]]
							
							local NGMoney = CreateFrame("Frame", uniqueCharGoldID, UINGold.ScrollFrame, "SmallMoneyFrameTemplate")
							NGMoney:SetPoint("Right", UINGold.name, "LEFT", 285, 0)
							MoneyFrame_SetType(NGMoney, "STATIC") -- seems to be necessary so that the total isn't wiped out when opening a mail box
							MoneyFrame_Update(uniqueCharGoldID, value["gold"])
							y = y - 20
							yRealmOffset = yRealmOffset - 20
							
							--print("yRealmOffset (inner most): " .. yRealmOffset)
							--print("y realm (in schleife): " .. yRealmOffset)
						end
					end
				end	
			end	
			--print("ENDE")
			
		end
		
		
		
		
	end
	--print("AFTER ENDE y/yRealmOffset @@@@@@@@@@  " .. y .. " / " .. yRealmOffset)
	
	-- set the scroll size
	child:SetSize(320, -yRealmOffset);
	
end

-- toggle GUI :D
function nakaGold_toggleGUI()

	local menu = UINGold or nakaGold_initGUI();
	menu:SetShown(not menu:IsShown());
	
end

-- check if a given table has a given key (no matter the content of the key)
function checkMinimapKey(table, key)
	return table[key] ~= nil
end

-- event handler
local function nakaGold_OnEvent(self, event, arg1, ...)
	if (event == "PLAYER_LOGIN") then
		icon:Register("nakaGold", LDB, minimapDB)
		
		-- initilize / check
		if not checkMinimapKey(minimapDB, "show") then
			--print("show NICHT vorhanden")
			minimapDB.show = true
		else
			--print("show vorhanden")
		end
		
		if not checkMinimapKey(minimapDB, "lock") then
			--print("lock NICHT vorhanden")
			minimapDB.lock = false
		else
			--print("lock vorhanden")
		end
		
		
		if minimapDB.show then
			C_Timer.After(1, function() icon:Show("nakaGold") end)
			--print("show")
		else
			C_Timer.After(1, function() icon:Hide("nakaGold") end)
			--print("hide aaaaaaaaaa")
		end
	end
	if (event == "ADDON_LOADED") then
		if (arg1 == "nakaGold") then
			nakaGold_initGUI()
			nakaGold_initMoney()
			SlashCommands()
			
			--[[			
			if not minimapDB[lock] then
				minimapDB.lock = false
			end
			]]
		end
	end
	
	if ( (event == "PLAYER_MONEY") or (event == "PLAYER_ENTERING_WORLD") ) then 
		nakaGold_current = GetMoney()
		--print("Gold currently: " .. " " .. nakaGold_current)
		nakaGold_goldUpdate()

	end
	
	if (event == "PLAYER_LEAVING_WORLD") then
		--nakaGold_goldUpdate()
	end
end


----------
-- Slash commands
----------
function SlashCommands()
	SLASH_RELOADUI1 = "/rl" -- For quicker reloading
	SlashCmdList.RELOADUI = ReloadUI

	SLASH_NAKAGOLD1 = "/ng"
	SLASH_NAKAGOLD2 = "/nakagold"
		
	SlashCmdList["NAKAGOLD"] = function(arg)
		arg = arg:lower()
		if arg == "show" then
			UINGold:Show()
		else
					
		end
		
		if #arg == 0 then
			nakaGold_toggleGUI()
		else
					
		end
		
		if arg == "hide" then
			UINGold:Hide()
		else
					
		end
		
		if arg == "toggle" then
			nakaGold_toggleGUI()
		else
					
		end
		
		if arg == "minimap" then
			if minimapDB.show == true then
				icon:Hide("nakaGold")
				minimapDB.show = false
			else
				icon:Show("nakaGold")
				minimapDB.show = true
			end
			
		else
		
		end
	end
end


----------
-- init
----------
UINGold:RegisterEvent("PLAYER_LOGIN")
UINGold:RegisterEvent("ADDON_LOADED")
UINGold:RegisterEvent("PLAYER_ENTERING_WORLD")
UINGold:RegisterEvent("PLAYER_MONEY")
UINGold:RegisterEvent("PLAYER_LEAVING_WORLD")

UINGold:SetScript("OnEvent", nakaGold_OnEvent)